netapp_ontap.models.zapp_s3_bucket_application_components_access_policies API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.zapp_s3_bucket_application_components_access_policies`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class ZappS3BucketApplicationComponentsAccessPoliciesSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the ZappS3BucketApplicationComponentsAccessPolicies object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `actions GET POST PATCH`

    The actions field of the zapp_s3_bucket_application_components_access_policies.

  `conditions GET POST`

    conditions.

  `effect GET POST`

    Allow or Deny Access.

    Valid choices:

    - allow
    - deny
  `principals GET POST PATCH`

    The principals field of the zapp_s3_bucket_application_components_access_policies.

  `resources GET POST PATCH`

    The resources field of the zapp_s3_bucket_application_components_access_policies.

  `sid GET POST`

    Statement Identifier Usage: <(size 1..256)>